/**
 * Copyright 2009-2012, Descartes Research Group, SDQ, IPD, KIT
 */
package tools.descartes.dml.mm.adaptation.util;

import org.eclipse.emf.common.notify.Adapter;
import org.eclipse.emf.common.notify.Notifier;
import org.eclipse.emf.common.notify.impl.AdapterFactoryImpl;
import org.eclipse.emf.ecore.EObject;

import tools.descartes.dml.core.Entity;
import tools.descartes.dml.core.NamedElement;
import tools.descartes.dml.identifier.Identifier;
//import tools.descartes.dml.mm.adaptation.*;
import tools.descartes.dml.mm.adaptation.AbstractControlFlowElement;
import tools.descartes.dml.mm.adaptation.Action;
import tools.descartes.dml.mm.adaptation.ActionReference;
import tools.descartes.dml.mm.adaptation.AdaptationActionOperation;
import tools.descartes.dml.mm.adaptation.AdaptationPackage;
import tools.descartes.dml.mm.adaptation.AdaptationPlan;
import tools.descartes.dml.mm.adaptation.AdaptationProcess;
import tools.descartes.dml.mm.adaptation.BranchAction;
import tools.descartes.dml.mm.adaptation.Event;
import tools.descartes.dml.mm.adaptation.ImportDeclaration;
import tools.descartes.dml.mm.adaptation.LoopAction;
import tools.descartes.dml.mm.adaptation.Objective;
import tools.descartes.dml.mm.adaptation.OverallGoal;
import tools.descartes.dml.mm.adaptation.Parameter;
import tools.descartes.dml.mm.adaptation.Specification;
import tools.descartes.dml.mm.adaptation.StartAction;
import tools.descartes.dml.mm.adaptation.StopAction;
import tools.descartes.dml.mm.adaptation.Strategy;
import tools.descartes.dml.mm.adaptation.Tactic;
import tools.descartes.dml.mm.adaptation.WeightedMetric;
import tools.descartes.dml.mm.adaptation.WeightedTactic;
import tools.descartes.dml.mm.adaptation.WeightingFunction;

/**
 * <!-- begin-user-doc -->
 * The <b>Adapter Factory</b> for the model.
 * It provides an adapter <code>createXXX</code> method for each class of the model.
 * <!-- end-user-doc -->
 * @see tools.descartes.dml.mm.adaptation.AdaptationPackage
 * @generated
 */
public class AdaptationAdapterFactory extends AdapterFactoryImpl {
    /**
	 * The cached model package.
	 * <!-- begin-user-doc -->
     * <!-- end-user-doc -->
	 * @generated
	 */
    protected static AdaptationPackage modelPackage;

    /**
	 * Creates an instance of the adapter factory.
	 * <!-- begin-user-doc -->
     * <!-- end-user-doc -->
	 * @generated
	 */
    public AdaptationAdapterFactory() {
		if (modelPackage == null) {
			modelPackage = AdaptationPackage.eINSTANCE;
		}
	}

    /**
	 * Returns whether this factory is applicable for the type of the object.
	 * <!-- begin-user-doc -->
     * This implementation returns <code>true</code> if the object is either the model's package or is an instance object of the model.
     * <!-- end-user-doc -->
	 * @return whether this factory is applicable for the type of the object.
	 * @generated
	 */
    @Override
    public boolean isFactoryForType(Object object) {
		if (object == modelPackage) {
			return true;
		}
		if (object instanceof EObject) {
			return ((EObject)object).eClass().getEPackage() == modelPackage;
		}
		return false;
	}

    /**
	 * The switch that delegates to the <code>createXXX</code> methods.
	 * <!-- begin-user-doc -->
     * <!-- end-user-doc -->
	 * @generated
	 */
    protected AdaptationSwitch<Adapter> modelSwitch =
        new AdaptationSwitch<Adapter>() {
			@Override
			public Adapter caseAdaptationProcess(AdaptationProcess object) {
				return createAdaptationProcessAdapter();
			}
			@Override
			public Adapter caseOverallGoal(OverallGoal object) {
				return createOverallGoalAdapter();
			}
			@Override
			public Adapter caseStrategy(Strategy object) {
				return createStrategyAdapter();
			}
			@Override
			public Adapter caseEvent(Event object) {
				return createEventAdapter();
			}
			@Override
			public Adapter caseObjective(Objective object) {
				return createObjectiveAdapter();
			}
			@Override
			public Adapter caseSpecification(Specification object) {
				return createSpecificationAdapter();
			}
			@Override
			public Adapter caseWeightingFunction(WeightingFunction object) {
				return createWeightingFunctionAdapter();
			}
			@Override
			public Adapter caseWeightedMetric(WeightedMetric object) {
				return createWeightedMetricAdapter();
			}
			@Override
			public Adapter caseWeightedTactic(WeightedTactic object) {
				return createWeightedTacticAdapter();
			}
			@Override
			public Adapter caseTactic(Tactic object) {
				return createTacticAdapter();
			}
			@Override
			public Adapter caseAbstractControlFlowElement(AbstractControlFlowElement object) {
				return createAbstractControlFlowElementAdapter();
			}
			@Override
			public Adapter caseStartAction(StartAction object) {
				return createStartActionAdapter();
			}
			@Override
			public Adapter caseStopAction(StopAction object) {
				return createStopActionAdapter();
			}
			@Override
			public Adapter caseLoopAction(LoopAction object) {
				return createLoopActionAdapter();
			}
			@Override
			public Adapter caseBranchAction(BranchAction object) {
				return createBranchActionAdapter();
			}
			@Override
			public Adapter caseActionReference(ActionReference object) {
				return createActionReferenceAdapter();
			}
			@Override
			public Adapter caseAdaptationPlan(AdaptationPlan object) {
				return createAdaptationPlanAdapter();
			}
			@Override
			public Adapter caseAction(Action object) {
				return createActionAdapter();
			}
			@Override
			public Adapter caseAdaptationActionOperation(AdaptationActionOperation object) {
				return createAdaptationActionOperationAdapter();
			}
			@Override
			public Adapter caseParameter(Parameter object) {
				return createParameterAdapter();
			}
			@Override
			public Adapter caseImportDeclaration(ImportDeclaration object) {
				return createImportDeclarationAdapter();
			}
			@Override
			public Adapter caseIdentifier(Identifier object) {
				return createIdentifierAdapter();
			}
			@Override
			public Adapter caseNamedElement(NamedElement object) {
				return createNamedElementAdapter();
			}
			@Override
			public Adapter caseEntity(Entity object) {
				return createEntityAdapter();
			}
			@Override
			public Adapter defaultCase(EObject object) {
				return createEObjectAdapter();
			}
		};

    /**
	 * Creates an adapter for the <code>target</code>.
	 * <!-- begin-user-doc -->
     * <!-- end-user-doc -->
	 * @param target the object to adapt.
	 * @return the adapter for the <code>target</code>.
	 * @generated
	 */
    @Override
    public Adapter createAdapter(Notifier target) {
		return modelSwitch.doSwitch((EObject)target);
	}


    /**
	 * Creates a new adapter for an object of class '{@link tools.descartes.dml.mm.adaptation.AdaptationProcess <em>Process</em>}'.
	 * <!-- begin-user-doc -->
     * This default implementation returns null so that we can easily ignore cases;
     * it's useful to ignore a case when inheritance will catch all the cases anyway.
     * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see tools.descartes.dml.mm.adaptation.AdaptationProcess
	 * @generated
	 */
    public Adapter createAdaptationProcessAdapter() {
		return null;
	}

    /**
	 * Creates a new adapter for an object of class '{@link tools.descartes.dml.mm.adaptation.OverallGoal <em>Overall Goal</em>}'.
	 * <!-- begin-user-doc -->
     * This default implementation returns null so that we can easily ignore cases;
     * it's useful to ignore a case when inheritance will catch all the cases anyway.
     * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see tools.descartes.dml.mm.adaptation.OverallGoal
	 * @generated
	 */
    public Adapter createOverallGoalAdapter() {
		return null;
	}

    /**
	 * Creates a new adapter for an object of class '{@link tools.descartes.dml.mm.adaptation.Strategy <em>Strategy</em>}'.
	 * <!-- begin-user-doc -->
     * This default implementation returns null so that we can easily ignore cases;
     * it's useful to ignore a case when inheritance will catch all the cases anyway.
     * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see tools.descartes.dml.mm.adaptation.Strategy
	 * @generated
	 */
    public Adapter createStrategyAdapter() {
		return null;
	}

    /**
	 * Creates a new adapter for an object of class '{@link tools.descartes.dml.mm.adaptation.Event <em>Event</em>}'.
	 * <!-- begin-user-doc -->
     * This default implementation returns null so that we can easily ignore cases;
     * it's useful to ignore a case when inheritance will catch all the cases anyway.
     * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see tools.descartes.dml.mm.adaptation.Event
	 * @generated
	 */
    public Adapter createEventAdapter() {
		return null;
	}

    /**
	 * Creates a new adapter for an object of class '{@link tools.descartes.dml.mm.adaptation.Objective <em>Objective</em>}'.
	 * <!-- begin-user-doc -->
     * This default implementation returns null so that we can easily ignore cases;
     * it's useful to ignore a case when inheritance will catch all the cases anyway.
     * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see tools.descartes.dml.mm.adaptation.Objective
	 * @generated
	 */
    public Adapter createObjectiveAdapter() {
		return null;
	}

    /**
	 * Creates a new adapter for an object of class '{@link tools.descartes.dml.mm.adaptation.Specification <em>Specification</em>}'.
	 * <!-- begin-user-doc -->
     * This default implementation returns null so that we can easily ignore cases;
     * it's useful to ignore a case when inheritance will catch all the cases anyway.
     * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see tools.descartes.dml.mm.adaptation.Specification
	 * @generated
	 */
    public Adapter createSpecificationAdapter() {
		return null;
	}

    /**
	 * Creates a new adapter for an object of class '{@link tools.descartes.dml.mm.adaptation.WeightingFunction <em>Weighting Function</em>}'.
	 * <!-- begin-user-doc -->
     * This default implementation returns null so that we can easily ignore cases;
     * it's useful to ignore a case when inheritance will catch all the cases anyway.
     * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see tools.descartes.dml.mm.adaptation.WeightingFunction
	 * @generated
	 */
    public Adapter createWeightingFunctionAdapter() {
		return null;
	}

    /**
	 * Creates a new adapter for an object of class '{@link tools.descartes.dml.mm.adaptation.WeightedMetric <em>Weighted Metric</em>}'.
	 * <!-- begin-user-doc -->
     * This default implementation returns null so that we can easily ignore cases;
     * it's useful to ignore a case when inheritance will catch all the cases anyway.
     * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see tools.descartes.dml.mm.adaptation.WeightedMetric
	 * @generated
	 */
    public Adapter createWeightedMetricAdapter() {
		return null;
	}

    /**
	 * Creates a new adapter for an object of class '{@link tools.descartes.dml.mm.adaptation.WeightedTactic <em>Weighted Tactic</em>}'.
	 * <!-- begin-user-doc -->
     * This default implementation returns null so that we can easily ignore cases;
     * it's useful to ignore a case when inheritance will catch all the cases anyway.
     * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see tools.descartes.dml.mm.adaptation.WeightedTactic
	 * @generated
	 */
    public Adapter createWeightedTacticAdapter() {
		return null;
	}

    /**
	 * Creates a new adapter for an object of class '{@link tools.descartes.dml.mm.adaptation.Tactic <em>Tactic</em>}'.
	 * <!-- begin-user-doc -->
     * This default implementation returns null so that we can easily ignore cases;
     * it's useful to ignore a case when inheritance will catch all the cases anyway.
     * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see tools.descartes.dml.mm.adaptation.Tactic
	 * @generated
	 */
    public Adapter createTacticAdapter() {
		return null;
	}

    /**
	 * Creates a new adapter for an object of class '{@link tools.descartes.dml.mm.adaptation.AbstractControlFlowElement <em>Abstract Control Flow Element</em>}'.
	 * <!-- begin-user-doc -->
     * This default implementation returns null so that we can easily ignore cases;
     * it's useful to ignore a case when inheritance will catch all the cases anyway.
     * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see tools.descartes.dml.mm.adaptation.AbstractControlFlowElement
	 * @generated
	 */
    public Adapter createAbstractControlFlowElementAdapter() {
		return null;
	}

    /**
	 * Creates a new adapter for an object of class '{@link tools.descartes.dml.mm.adaptation.StartAction <em>Start Action</em>}'.
	 * <!-- begin-user-doc -->
     * This default implementation returns null so that we can easily ignore cases;
     * it's useful to ignore a case when inheritance will catch all the cases anyway.
     * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see tools.descartes.dml.mm.adaptation.StartAction
	 * @generated
	 */
    public Adapter createStartActionAdapter() {
		return null;
	}

    /**
	 * Creates a new adapter for an object of class '{@link tools.descartes.dml.mm.adaptation.StopAction <em>Stop Action</em>}'.
	 * <!-- begin-user-doc -->
     * This default implementation returns null so that we can easily ignore cases;
     * it's useful to ignore a case when inheritance will catch all the cases anyway.
     * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see tools.descartes.dml.mm.adaptation.StopAction
	 * @generated
	 */
    public Adapter createStopActionAdapter() {
		return null;
	}

    /**
	 * Creates a new adapter for an object of class '{@link tools.descartes.dml.mm.adaptation.LoopAction <em>Loop Action</em>}'.
	 * <!-- begin-user-doc -->
     * This default implementation returns null so that we can easily ignore cases;
     * it's useful to ignore a case when inheritance will catch all the cases anyway.
     * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see tools.descartes.dml.mm.adaptation.LoopAction
	 * @generated
	 */
    public Adapter createLoopActionAdapter() {
		return null;
	}

    /**
	 * Creates a new adapter for an object of class '{@link tools.descartes.dml.mm.adaptation.BranchAction <em>Branch Action</em>}'.
	 * <!-- begin-user-doc -->
     * This default implementation returns null so that we can easily ignore cases;
     * it's useful to ignore a case when inheritance will catch all the cases anyway.
     * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see tools.descartes.dml.mm.adaptation.BranchAction
	 * @generated
	 */
    public Adapter createBranchActionAdapter() {
		return null;
	}

    /**
	 * Creates a new adapter for an object of class '{@link tools.descartes.dml.mm.adaptation.ActionReference <em>Action Reference</em>}'.
	 * <!-- begin-user-doc -->
     * This default implementation returns null so that we can easily ignore cases;
     * it's useful to ignore a case when inheritance will catch all the cases anyway.
     * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see tools.descartes.dml.mm.adaptation.ActionReference
	 * @generated
	 */
    public Adapter createActionReferenceAdapter() {
		return null;
	}

    /**
	 * Creates a new adapter for an object of class '{@link tools.descartes.dml.mm.adaptation.AdaptationPlan <em>Plan</em>}'.
	 * <!-- begin-user-doc -->
     * This default implementation returns null so that we can easily ignore cases;
     * it's useful to ignore a case when inheritance will catch all the cases anyway.
     * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see tools.descartes.dml.mm.adaptation.AdaptationPlan
	 * @generated
	 */
    public Adapter createAdaptationPlanAdapter() {
		return null;
	}

    /**
	 * Creates a new adapter for an object of class '{@link tools.descartes.dml.mm.adaptation.Action <em>Action</em>}'.
	 * <!-- begin-user-doc -->
     * This default implementation returns null so that we can easily ignore cases;
     * it's useful to ignore a case when inheritance will catch all the cases anyway.
     * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see tools.descartes.dml.mm.adaptation.Action
	 * @generated
	 */
    public Adapter createActionAdapter() {
		return null;
	}

    /**
	 * Creates a new adapter for an object of class '{@link tools.descartes.dml.mm.adaptation.AdaptationActionOperation <em>Action Operation</em>}'.
	 * <!-- begin-user-doc -->
     * This default implementation returns null so that we can easily ignore cases;
     * it's useful to ignore a case when inheritance will catch all the cases anyway.
     * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see tools.descartes.dml.mm.adaptation.AdaptationActionOperation
	 * @generated
	 */
    public Adapter createAdaptationActionOperationAdapter() {
		return null;
	}

    /**
	 * Creates a new adapter for an object of class '{@link tools.descartes.dml.mm.adaptation.Parameter <em>Parameter</em>}'.
	 * <!-- begin-user-doc -->
     * This default implementation returns null so that we can easily ignore cases;
     * it's useful to ignore a case when inheritance will catch all the cases anyway.
     * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see tools.descartes.dml.mm.adaptation.Parameter
	 * @generated
	 */
    public Adapter createParameterAdapter() {
		return null;
	}

    /**
	 * Creates a new adapter for an object of class '{@link tools.descartes.dml.mm.adaptation.ImportDeclaration <em>Import Declaration</em>}'.
	 * <!-- begin-user-doc -->
     * This default implementation returns null so that we can easily ignore cases;
     * it's useful to ignore a case when inheritance will catch all the cases anyway.
     * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see tools.descartes.dml.mm.adaptation.ImportDeclaration
	 * @generated
	 */
    public Adapter createImportDeclarationAdapter() {
		return null;
	}

    /**
	 * Creates a new adapter for an object of class '{@link tools.descartes.dml.identifier.Identifier <em>Identifier</em>}'.
	 * <!-- begin-user-doc -->
     * This default implementation returns null so that we can easily ignore cases;
     * it's useful to ignore a case when inheritance will catch all the cases anyway.
     * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see tools.descartes.dml.identifier.Identifier
	 * @generated
	 */
    public Adapter createIdentifierAdapter() {
		return null;
	}

    /**
	 * Creates a new adapter for an object of class '{@link tools.descartes.dml.core.NamedElement <em>Named Element</em>}'.
	 * <!-- begin-user-doc -->
     * This default implementation returns null so that we can easily ignore cases;
     * it's useful to ignore a case when inheritance will catch all the cases anyway.
     * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see tools.descartes.dml.core.NamedElement
	 * @generated
	 */
    public Adapter createNamedElementAdapter() {
		return null;
	}

    /**
	 * Creates a new adapter for an object of class '{@link tools.descartes.dml.core.Entity <em>Entity</em>}'.
	 * <!-- begin-user-doc -->
     * This default implementation returns null so that we can easily ignore cases;
     * it's useful to ignore a case when inheritance will catch all the cases anyway.
     * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @see tools.descartes.dml.core.Entity
	 * @generated
	 */
    public Adapter createEntityAdapter() {
		return null;
	}

    /**
	 * Creates a new adapter for the default case.
	 * <!-- begin-user-doc -->
     * This default implementation returns null.
     * <!-- end-user-doc -->
	 * @return the new adapter.
	 * @generated
	 */
    public Adapter createEObjectAdapter() {
		return null;
	}

} //AdaptationAdapterFactory
