package tools.descartes.dml.mm.applicationlevel.functions.util.tests;

import org.junit.Assert;
import org.junit.Test;

import tools.descartes.dml.mm.applicationlevel.functions.RandomVariable;
import tools.descartes.dml.mm.applicationlevel.functions.util.RandomVariableHelper;

public class PMFMeanTest extends AbstractRandomVariableHelperTest {

	@Test
	public void intPMFUnaryTest() {
		RandomVariable randomVariable = loadModel("testfiles/int-pmf-unary.functions", RandomVariable.class);
		Assert.assertEquals(100, RandomVariableHelper.getNumericalMean(randomVariable.getProbFunction()), 0.0001);
	}

	@Test
	public void intPMFUniformTest() {
		RandomVariable randomVariable = loadModel("testfiles/int-pmf-uniform-distrib.functions", RandomVariable.class);
		Assert.assertEquals(3.5, RandomVariableHelper.getNumericalMean(randomVariable.getProbFunction()), 0.0001);
	}

	@Test
	public void intPMFNegativeUniformTest() {
		RandomVariable randomVariable = loadModel("testfiles/int-pmf-negative.functions", RandomVariable.class);
		Assert.assertEquals(-3.5, RandomVariableHelper.getNumericalMean(randomVariable.getProbFunction()), 0.0001);
	}

	@Test
	public void doublePMFTest() {
		RandomVariable randomVariable = loadModel("testfiles/double-pmf.functions", RandomVariable.class);
		Assert.assertEquals(1042.65172, RandomVariableHelper.getNumericalMean(randomVariable.getProbFunction()),
				0.00001);
	}

	@Test
	public void doublePMFUnaryTest() {
		RandomVariable randomVariable = loadModel("testfiles/double-pmf-unary.functions", RandomVariable.class);
		Assert.assertEquals(0.1, RandomVariableHelper.getNumericalMean(randomVariable.getProbFunction()), 0.00001);
	}

	@Test
	public void doublePMFUniformDistribTest() {
		RandomVariable randomVariable = loadModel("testfiles/double-pmf-uniform-distrib.functions",
				RandomVariable.class);
		Assert.assertEquals(0.35, RandomVariableHelper.getNumericalMean(randomVariable.getProbFunction()), 0.00001);
	}

	@Test
	public void doublePMFNegativeUniformDistribTest() {
		RandomVariable randomVariable = loadModel("testfiles/double-pmf-negative.functions", RandomVariable.class);
		Assert.assertEquals(-0.35, RandomVariableHelper.getNumericalMean(randomVariable.getProbFunction()), 0.00001);
	}

	@Test(expected = UnsupportedOperationException.class)
	public void booleanPMFTest() {
		RandomVariable randomVariable = loadModel("testfiles/boolean-pmf.functions", RandomVariable.class);
		RandomVariableHelper.getNumericalMean(randomVariable.getProbFunction());
	}

	@Test(expected = UnsupportedOperationException.class)
	public void enumPMFTest() {
		RandomVariable randomVariable = loadModel("testfiles/enum-pmf.functions", RandomVariable.class);
		RandomVariableHelper.getNumericalMean(randomVariable.getProbFunction());
	}
}
