/**
 * Copyright 2009-2012, Descartes Research Group, SDQ, IPD, KIT
 */
package tools.descartes.dml.mm.applicationlevel.parameterdependencies.provider;


import java.util.Collection;
import java.util.List;

import org.eclipse.emf.common.notify.AdapterFactory;
import org.eclipse.emf.common.notify.Notification;
import org.eclipse.emf.common.util.ResourceLocator;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.edit.provider.ComposeableAdapterFactory;
import org.eclipse.emf.edit.provider.IItemPropertyDescriptor;
import org.eclipse.emf.edit.provider.ItemPropertyDescriptor;
import org.eclipse.emf.edit.provider.ViewerNotification;

import tools.descartes.dml.mm.applicationlevel.parameterdependencies.CallParameter;
import tools.descartes.dml.mm.applicationlevel.parameterdependencies.ParameterCharacterizationType;
import tools.descartes.dml.mm.applicationlevel.parameterdependencies.ParameterdependenciesPackage;
import tools.descartes.dml.mm.applicationlevel.provider.ApplicationlevelEditPlugin;
import tools.descartes.dml.mm.applicationlevel.repository.BasicComponent;
import tools.descartes.dml.mm.applicationlevel.repository.Parameter;
import tools.descartes.dml.mm.applicationlevel.servicebehavior.ServiceBehaviorAbstraction;
import tools.descartes.dml.mm.applicationlevel.servicebehavior.provider.RelationshipVariableItemProvider;
import tools.descartes.dml.mm.applicationlevel.util.CustomListenerComponent;
import tools.descartes.dml.mm.applicationlevel.util.NavigationUtil;

/**
 * This is the item provider adapter for a {@link tools.descartes.dml.mm.applicationlevel.parameterdependencies.CallParameter} object.
 * <!-- begin-user-doc -->
 * <!-- end-user-doc -->
 * @generated
 */
public class CallParameterItemProvider extends RelationshipVariableItemProvider {
	
	private CustomListenerComponent parameterListenerConmponent = new CustomListenerComponent(this);
	/**
	 * This constructs an instance from a factory and a notifier.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public CallParameterItemProvider(AdapterFactory adapterFactory) {
		super(adapterFactory);
	}

	/**
	 * This returns the property descriptors for the adapted class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	@Override
	public List<IItemPropertyDescriptor> getPropertyDescriptors(Object object) {
		if (itemPropertyDescriptors == null) {
			super.getPropertyDescriptors(object);

			addParameterCharacterizationPropertyDescriptor(object);
		}
		return itemPropertyDescriptors;
	}

	/**
	 * This adds a property descriptor for the Parameter Characterization feature.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	protected void addParameterCharacterizationPropertyDescriptor(Object object) {
		itemPropertyDescriptors.add
			(createItemPropertyDescriptor
				(((ComposeableAdapterFactory)adapterFactory).getRootAdapterFactory(),
				 getResourceLocator(),
				 getString("_UI_CallParameter_parameterCharacterization_feature"),
				 getString("_UI_PropertyDescriptor_description", "_UI_CallParameter_parameterCharacterization_feature", "_UI_CallParameter_type"),
				 ParameterdependenciesPackage.Literals.CALL_PARAMETER__PARAMETER_CHARACTERIZATION,
				 true,
				 false,
				 false,
				 ItemPropertyDescriptor.GENERIC_VALUE_IMAGE,
				 null,
				 null));
	}

	/**
	 * This returns the label text for the adapted class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated NOT
	 */
	@Override
	public String getText(Object object) {
		Parameter parameter = ((CallParameter)object).getParameter();
		ServiceBehaviorAbstraction beh = NavigationUtil
				.getParentbehavior((EObject) object);
		BasicComponent parent = NavigationUtil.getParentComponent(beh);
		if (parent == null)
			return null;
		ParameterCharacterizationType characterization = ((CallParameter) object).getParameterCharacterization();
		String text = " ";
		if (parent.getName() != null) {
			text += parent.getName();
			if (beh.getDescribedSignature() != null || parameter != null)
				text += "/";
		}
		if (beh.getDescribedSignature() != null)
			if (beh.getDescribedSignature().getName() != null) {
				text += beh.getDescribedSignature().getName();
				if (parameter != null)
					text += "/";
			}
		if (parameter != null) {
			parameterListenerConmponent.tryToUpdateListeners(object, parameter);
			text += parameter.getName();
			if (characterization != null) {
				text += "." + characterization.getName();
			}
		}
		return text;
	}
	

	/**
	 * This handles model notifications by calling {@link #updateChildren} to update any cached
	 * children and by creating a viewer notification, which it passes to {@link #fireNotifyChanged}.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated NOT
	 */
	@Override
	public void notifyChanged(Notification notification) {
		updateChildren(notification);

		switch (notification.getFeatureID(CallParameter.class)) {
		case ParameterdependenciesPackage.CALL_PARAMETER__CHARACTERIZATION:
			fireNotifyChanged(new ViewerNotification(notification, notification.getNotifier(), false, true));
			return;
		case ParameterdependenciesPackage.CALL_PARAMETER:
				fireNotifyChanged(new ViewerNotification(notification, notification.getNotifier(), false, true));
				return;
		}
		super.notifyChanged(notification);
	}

	/**
	 * This adds {@link org.eclipse.emf.edit.command.CommandParameter}s describing the children
	 * that can be created under this object.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	@Override
	protected void collectNewChildDescriptors(Collection<Object> newChildDescriptors, Object object) {
		super.collectNewChildDescriptors(newChildDescriptors, object);
	}

	/**
	 * Return the resource locator for this item provider's resources.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	@Override
	public ResourceLocator getResourceLocator() {
		return ApplicationlevelEditPlugin.INSTANCE;
	}

}
