/**
 * Copyright 2009-2012, Descartes Research Group, SDQ, IPD, KIT
 */
package tools.descartes.dml.mm.applicationlevel.parameterdependencies.provider;


import java.util.Collection;
import java.util.List;

import org.eclipse.emf.common.notify.AdapterFactory;
import org.eclipse.emf.common.notify.Notification;
import org.eclipse.emf.edit.provider.ComposeableAdapterFactory;
import org.eclipse.emf.edit.provider.IItemPropertyDescriptor;
import org.eclipse.emf.edit.provider.ViewerNotification;

import tools.descartes.dml.mm.applicationlevel.parameterdependencies.CallParameter;
import tools.descartes.dml.mm.applicationlevel.parameterdependencies.ExternalCallParameter;
import tools.descartes.dml.mm.applicationlevel.parameterdependencies.ParameterdependenciesPackage;
import tools.descartes.dml.mm.applicationlevel.repository.InputParameter;
import tools.descartes.dml.mm.applicationlevel.repository.Parameter;
import tools.descartes.dml.mm.applicationlevel.servicebehavior.ServiceBehaviorAbstraction;
import tools.descartes.dml.mm.applicationlevel.util.CustomItemPropertyDescriptor;
import tools.descartes.dml.mm.applicationlevel.util.NavigationCommand;
import tools.descartes.dml.mm.applicationlevel.util.NavigationUtil;

/**
 * This is the item provider adapter for a {@link tools.descartes.dml.mm.applicationlevel.parameterdependencies.ExternalCallParameter} object.
 * <!-- begin-user-doc -->
 * <!-- end-user-doc -->
 * @generated
 */
public class ExternalCallParameterItemProvider extends CallParameterItemProvider {
	/**
	 * This constructs an instance from a factory and a notifier.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public ExternalCallParameterItemProvider(AdapterFactory adapterFactory) {
		super(adapterFactory);
	}

	/**
	 * This returns the property descriptors for the adapted class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	@Override
	public List<IItemPropertyDescriptor> getPropertyDescriptors(Object object) {
		if (itemPropertyDescriptors == null) {
			super.getPropertyDescriptors(object);

			addExternalCallPropertyDescriptor(object);
			addParameterPropertyDescriptor(object);
		}
		return itemPropertyDescriptors;
	}

	/**
	 * This adds a property descriptor for the External Call feature.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated NOT
	 */
	protected void addExternalCallPropertyDescriptor(Object object) {
		NavigationCommand command = new NavigationCommand() {
			@Override
			public Collection<?> navigate(Object object) {
				ExternalCallParameter callParameter = (ExternalCallParameter)object;
				ServiceBehaviorAbstraction behavior = (ServiceBehaviorAbstraction) NavigationUtil
						.getParentOf(callParameter);
				return NavigationUtil.getExternalCalls(behavior);
			}
		};
		itemPropertyDescriptors.add
			(new CustomItemPropertyDescriptor
				(((ComposeableAdapterFactory)adapterFactory).getRootAdapterFactory(),
				 getResourceLocator(),
				 getString("_UI_ExternalCallParameter_externalCall_feature"),
				 getString("_UI_PropertyDescriptor_description", "_UI_ExternalCallParameter_externalCall_feature", "_UI_ExternalCallParameter_type"),
				 ParameterdependenciesPackage.Literals.EXTERNAL_CALL_PARAMETER__EXTERNAL_CALL,
				 true,
				 false,
				 true,
				 null,
				 null,
				 null,
				 command));
	}

	/**
	 * This adds a property descriptor for the Parameter feature.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated NOT
	 */
	protected void addParameterPropertyDescriptor(Object object) {
		NavigationCommand command = new NavigationCommand() {
			@Override
			public Collection<?> navigate(Object object) {
				ExternalCallParameter callParameter = (ExternalCallParameter)object;
				if (callParameter.getExternalCall() == null ||
					callParameter.getExternalCall().getSignature() == null)
				return null;
				List<Parameter> parameters = callParameter.getExternalCall()
						.getSignature().getParameters();
				return NavigationUtil.getObjectsWithClass(parameters, InputParameter.class);
			}
		};
		itemPropertyDescriptors.add
			(new CustomItemPropertyDescriptor
				(((ComposeableAdapterFactory)adapterFactory).getRootAdapterFactory(),
				 getResourceLocator(),
				 getString("_UI_ExternalCallParameter_parameter_feature"),
				 getString("_UI_PropertyDescriptor_description", "_UI_ExternalCallParameter_parameter_feature", "_UI_ExternalCallParameter_type"),
				 ParameterdependenciesPackage.Literals.EXTERNAL_CALL_PARAMETER__PARAMETER,
				 true,
				 false,
				 true,
				 null,
				 null,
				 null,
				 command));
	}

	/**
	 * This returns ExternalCallParameter.gif.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	@Override
	public Object getImage(Object object) {
		return overlayImage(object, getResourceLocator().getImage("full/obj16/ExternalCallParameter"));
	}

	/**
	 * This returns the label text for the adapted class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated NOT
	 */
	@Override
	public String getText(Object object) {
		String externalCallName = "";
		ExternalCallParameter callParameter = (ExternalCallParameter) object;
		if (callParameter.getExternalCall() != null)
			if (callParameter.getExternalCall().getName() != null)
				externalCallName = "/" + callParameter.getExternalCall().getName();
		return getString("_UI_ExternalCallParameter_type") + super.getText(object) + externalCallName;
	}
	

	/**
	 * This handles model notifications by calling {@link #updateChildren} to
	 * update any cached children and by creating a viewer notification, which
	 * it passes to {@link #fireNotifyChanged}. <!-- begin-user-doc --> <!--
	 * end-user-doc -->
	 * 
	 * @generated NOT
	 */
	@Override
	public void notifyChanged(Notification notification) {
		updateChildren(notification);

		switch (notification.getFeatureID(CallParameter.class)) {
		case ParameterdependenciesPackage.EXTERNAL_CALL_PARAMETER__PARAMETER:
			fireNotifyChanged(new ViewerNotification(notification, notification.getNotifier(), false, true));
			return;
		}

		super.notifyChanged(notification);
	}

	/**
	 * This adds {@link org.eclipse.emf.edit.command.CommandParameter}s describing the children
	 * that can be created under this object.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	@Override
	protected void collectNewChildDescriptors(Collection<Object> newChildDescriptors, Object object) {
		super.collectNewChildDescriptors(newChildDescriptors, object);
	}

}
