package tools.descartes.dml.mm.applicationlevel.util;

import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

import org.eclipse.emf.common.notify.AdapterFactory;
import org.eclipse.emf.common.notify.Notification;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.edit.provider.IChangeNotifier;
import org.eclipse.emf.edit.provider.INotifyChangedListener;
import org.eclipse.emf.edit.provider.ViewerNotification;

import tools.descartes.dml.mm.applicationlevel.parameterdependencies.provider.ParameterdependenciesItemProviderAdapterFactory;
import tools.descartes.dml.mm.applicationlevel.repository.provider.RepositoryItemProviderAdapterFactory;
import tools.descartes.dml.mm.applicationlevel.servicebehavior.provider.ServicebehaviorItemProviderAdapterFactory;
import tools.descartes.dml.mm.applicationlevel.system.provider.SystemItemProviderAdapterFactory;

public class CustomListenerComponent {
	private IChangeNotifier changeNotifier;
	private Map<Object, Set<Object>> existingListenerMap =
			new HashMap<Object, Set<Object>>();
	
	public CustomListenerComponent(IChangeNotifier changeNotifier) {
		this.changeNotifier = changeNotifier;
	}
	
	public void tryToUpdateListeners(Object listener, Object listenee) {
		IChangeNotifier itemprovider = getItemProvider(listenee);
		
		if (!existingListenerMap.containsKey(listenee)) {
			existingListenerMap.put(listenee, new HashSet<Object>());
		}
	   
	    if (!existingListenerMap.get(listenee).contains(listener)) {
	       itemprovider.addListener(createListener(listener, listenee));
	       existingListenerMap.get(listenee).add(listener);
	    }
	}
	
	private IChangeNotifier getItemProvider(Object listenee) {
		IChangeNotifier icn = null;
		if (icn == null)
			icn = tryToGetItemProvider(listenee, new ParameterdependenciesItemProviderAdapterFactory());
		if (icn == null)
			icn = tryToGetItemProvider(listenee, new RepositoryItemProviderAdapterFactory());
		if (icn == null)
			icn = tryToGetItemProvider(listenee, new ServicebehaviorItemProviderAdapterFactory());
		if (icn == null)
			icn = tryToGetItemProvider(listenee, new SystemItemProviderAdapterFactory());
		return icn;
	}
	
	private IChangeNotifier tryToGetItemProvider(Object listenee,
			AdapterFactory adapterFactory) {
		//Why is this EObject cast necessary? *confused*
		return (IChangeNotifier) adapterFactory.adapt(
				(EObject)listenee, listenee.getClass());
	}
	
	private INotifyChangedListener createListener(Object listener, Object listenee) {
		final Object finalListener = listener;
		final Object finalListenee = listenee;
		return new INotifyChangedListener() {
			   	@Override
			   	public void notifyChanged(Notification notification) {
			   		if (notification.getNotifier()==finalListenee) {
			   			changeNotifier.fireNotifyChanged(new ViewerNotification(
			   					notification, finalListener, false, true));
			   		}
			   	}
			};
	}
}
