package tools.descartes.dml.mm.applicationlevel.util;

import java.util.Collection;
import java.util.Collections;
import java.util.LinkedList;
import java.util.List;

import org.eclipse.emf.cdo.eresource.CDOResource;
import org.eclipse.emf.cdo.eresource.CDOResourceNode;
import org.eclipse.emf.cdo.view.CDOView;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.resource.Resource;

import tools.descartes.dml.mm.applicationlevel.parameterdependencies.Relationship;
import tools.descartes.dml.mm.applicationlevel.repository.BasicComponent;
import tools.descartes.dml.mm.applicationlevel.servicebehavior.AbstractAction;
import tools.descartes.dml.mm.applicationlevel.servicebehavior.BranchAction;
import tools.descartes.dml.mm.applicationlevel.servicebehavior.CoarseGrainedBehavior;
import tools.descartes.dml.mm.applicationlevel.servicebehavior.ComponentInternalBehavior;
import tools.descartes.dml.mm.applicationlevel.servicebehavior.ExternalCall;
import tools.descartes.dml.mm.applicationlevel.servicebehavior.ExternalCallAction;
import tools.descartes.dml.mm.applicationlevel.servicebehavior.ExternalCallFrequency;
import tools.descartes.dml.mm.applicationlevel.servicebehavior.FineGrainedBehavior;
import tools.descartes.dml.mm.applicationlevel.servicebehavior.ForkAction;
import tools.descartes.dml.mm.applicationlevel.servicebehavior.LoopAction;
import tools.descartes.dml.mm.applicationlevel.servicebehavior.ServiceBehaviorAbstraction;

public class NavigationUtil {

	public static EObject getParentOf(EObject eObject) {
		if (eObject == null) {
			return null;
		}

		EObject container = eObject.eContainer();
		if (container != null) {
			return container;
		}

		if (eObject instanceof CDOResource) {
			CDOResource resource = (CDOResource) eObject;
			if (resource.isRoot()) {
				return null;
			}
		}

		Resource resource = eObject.eResource();
		if (resource instanceof CDOResource) {
			return (CDOResource) resource;
		}

		if (eObject instanceof CDOResourceNode) {
			CDOView view = ((CDOResourceNode) eObject).cdoView();
			if (view != null) {
				return view.getRootResource();
			}
		}

		return null;
	}

	public static Relationship getParentRelationship(EObject obj) {
		while (obj != null && !(obj instanceof Relationship))
			obj = getParentOf(obj);
		return (Relationship) obj;
	}

	public static BasicComponent getParentComponent(EObject obj) {
		while (obj != null && !(obj instanceof BasicComponent))
			obj = getParentOf(obj);
		return (BasicComponent) obj;
	}

	public static ServiceBehaviorAbstraction getParentbehavior(EObject obj) {
		while (obj != null && !(obj instanceof ServiceBehaviorAbstraction))
				obj = getParentOf(obj);
		return (ServiceBehaviorAbstraction) obj;
	}

	public static List<Object> getObjectsWithClass(Collection<?> collection, Class<?> clazz) {
		List<Object> list = new LinkedList<Object>();
		for (Object o: collection)
			if (clazz.isInstance(o))
				list.add(o);
		return list;
	}

	public static List<?> getExternalCalls(ServiceBehaviorAbstraction behavior) {
		if (behavior instanceof CoarseGrainedBehavior) {
			List<Object> results = new LinkedList<Object>();
			List<ExternalCallFrequency> freqs = 
					((CoarseGrainedBehavior)behavior).getExternalCallFrequency();
			for (ExternalCallFrequency freq: freqs) {
				if (freq.getExternalCall() != null)
					results.add(freq.getExternalCall());
			}
				return results;
		} else {
			FineGrainedBehavior beh = (FineGrainedBehavior)behavior;
			return NavigationUtil.getExternalCalls(beh);
		}
	}

	private static List<ExternalCall> getExternalCalls(FineGrainedBehavior beh) {
		if (beh.getBehavior() != null)
			return getExternalCalls(beh.getBehavior());
		return Collections.emptyList();
	}
	
	private static List<ExternalCall> getExternalCalls(ComponentInternalBehavior beh) {
		List<ExternalCall> externalCalls = new LinkedList<ExternalCall>(); 
		for (AbstractAction aa: beh.getActions()) {
			if (aa instanceof ForkAction)  {
				ForkAction forkAction = (ForkAction)aa;
				for (ComponentInternalBehavior iBeh: forkAction.getForkedBehaviors())
					externalCalls.addAll(getExternalCalls(iBeh));
			}
			if (aa instanceof BranchAction) {
				BranchAction branchAction = (BranchAction)aa;
				for (ComponentInternalBehavior iBeh: branchAction.getBranches())
					externalCalls.addAll(getExternalCalls(iBeh));
			}
			if (aa instanceof LoopAction) {
				LoopAction loopAction = (LoopAction)aa;
				if (loopAction.getLoopBodyBehavior() != null) {
					ComponentInternalBehavior iBeh = loopAction.getLoopBodyBehavior();
					externalCalls.addAll(getExternalCalls(iBeh));
				}
			}
			if (aa instanceof ExternalCallAction) {
				ExternalCallAction externalCallAction = (ExternalCallAction)aa;
				if (externalCallAction.getExternalCall() != null)
					externalCalls.add(externalCallAction.getExternalCall());
			}
		}
		return externalCalls;
	}
}
